# Infinite-Campus-API
### Description
This project is an API for Infinite Campus. It is designed to be easy to use and understand. With this API, you can retrieve student's grades, courses and assignments and more with ease!
### Note
I cannot guarantee that this will work for every school district or even individual accounts. I am only able to test this with the one school district and the select number of accounts I have access to. If you encounter a problem with this package, create a new issue and I will attempt to review it.
